;; Generated package description from xml-rpc.el  -*- no-byte-compile: t -*-
(define-package "xml-rpc" "1.6.17" "An elisp implementation of clientside XML-RPC" '((emacs "24.1")) :commit "47cd3409d6c376adc6b9e46c30b1033289ddfb49" :maintainer '("Mark A. Hershberger" . "mah@everybody.org") :keywords '("xml" "rpc" "network" "comm") :url "http://github.com/xml-rpc-el/xml-rpc-el")
